@@ -31,36 +31,37 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-'''
+"""
 Processes ROS changelogs so that they can be used in binary packaging.
 
 The Changelog format is described in REP-0132:
 
 http://ros.org/reps/rep-0132.html
-'''
+"""
 
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import logging
+import os
+import re
 import sys
-_py3 = sys.version_info[0] >= 3
 
 import dateutil.parser
 import docutils
 import docutils.core
-import logging
-import os
 import pkg_resources
-import re
+
+_py3 = sys.version_info[0] >= 3
 
 try:
     _unicode = unicode
 except NameError:
     _unicode = str
 
-__author__ = "William Woodall"
-__email__ = "william@osrfoundation.org"
-__maintainer__ = "William Woodall"
+__author__ = 'William Woodall'
+__email__ = 'william@osrfoundation.org'
+__maintainer__ = 'William Woodall'
 
 log = logging.getLogger('changelog')
 
@@ -124,13 +125,13 @@ The library should now compile under ``Win32``
 
 
 def bullet_list_class_from_docutils(bullet_list, bullet_type=None):
-    '''
-    Processes elements of bullet list into an encapsulating class
+    """
+    Process elements of bullet list into an encapsulating class.
 
     :param bullet_list: ``docutils.nodes.bullet_list`` list to be processed
     :param bullet_type: ``str`` either 'bullet' or 'enumerated'
     :returns: ``BulletList`` object representing a docutils bullet_list
-    '''
+    """
     content = BulletList(bullet_type=bullet_type)
     for child in bullet_list.children:
         if isinstance(child, docutils.nodes.list_item):
@@ -141,12 +142,12 @@ def bullet_list_class_from_docutils(bullet_list, bullet_type=None):
 
 
 def mixed_text_from_docutils(node):
-    '''
-    Takes most Text-ish docutils objects and converts them to MixedText
+    """
+    Take most Text-ish docutils objects and converts them to MixedText.
 
     :param node: ``docutils.nodes.{paragraph, list_item, ...}`` text-ish
     :returns: ``MixedText`` representing the given docutils object
-    '''
+    """
     content = MixedText()
     for child in node.children:
         if isinstance(child, docutils.nodes.paragraph):
@@ -166,7 +167,7 @@ def mixed_text_from_docutils(node):
         elif isinstance(child, docutils.nodes.target):
             pass
         elif isinstance(child, docutils.nodes.system_message):
-            log.debug("Skipping system_message: {0}".format(child))
+            log.debug('Skipping system_message: {0}'.format(child))
         elif isinstance(child, docutils.nodes.bullet_list):
             content.texts.append(bullet_list_class_from_docutils(child))
         else:
@@ -182,13 +183,13 @@ def mixed_text_from_docutils(node):
 
 
 def get_changelog_from_path(path, package_name=None):
-    '''
-    Changelog factory, which reads a changelog file into a class
+    """
+    Changelog factory, which reads a changelog file into a class.
 
     :param path: ``str`` the path of the changelog including or excluding the filename CHANGELOG.rst
     :param package_name: ``str`` the package name
     :returns: ``Changelog`` changelog class or None if file was not readable
-    '''
+    """
     changelog = Changelog(package_name)
     if os.path.isdir(path):
         path = os.path.join(path, CHANGELOG_FILENAME)
@@ -201,13 +202,13 @@ def get_changelog_from_path(path, package_name=None):
 
 
 def populate_changelog_from_rst(changelog, rst):
-    '''
-    Changelog factory, which converts the raw ReST into a class
+    """
+    Changelog factory, which converts the raw ReST into a class.
 
     :param changelog: ``Changelog`` changelog to be populated
     :param rst: ``str`` raw ReST changelog
     :returns: ``Changelog`` changelog that was populated
-    '''
+    """
     document = docutils.core.publish_doctree(rst)
     processes_changelog_children(changelog, document.children)
     changelog.rst = rst
@@ -215,14 +216,15 @@ def populate_changelog_from_rst(changelog, rst):
 
 
 def processes_changelog_children(changelog, children):
-    '''
-    Processes docutils children into a REP-0132 changelog instance.
+    """
+    Process docutils children into a REP-0132 changelog instance.
+
     Recurse into sections, check (sub-)titles if they are valid versions.
 
     :param changelog: ``Changelog`` changelog to be populated
     :param section: ``docutils.nodes.section`` section to be processed
     :returns: ``Changelog`` changelog that was populated
-    '''
+    """
     for i, child in enumerate(children):
         if isinstance(child, docutils.nodes.section):
             processes_changelog_children(changelog, child.children)
@@ -272,12 +274,12 @@ def processes_changelog_children(changelog, children):
 
 
 def reference_from_docutils(reference):
-    '''
-    Turns a reference element into a ``Reference``
+    """
+    Turn a reference element into a ``Reference``.
 
     :param reference: ``docutils.nodes.reference`` reference element
     :returns: ``Reference`` simpler object representing the reference
-    '''
+    """
     name, refuri = None, None
     for pair in reference.attlist():
         if pair[0] == 'name':
@@ -288,13 +290,13 @@ def reference_from_docutils(reference):
 
 
 def version_and_date_from_title(title):
-    '''
-    Splits a section title into version and date if possible.
+    """
+    Split a section title into version and date if possible.
 
     :param title: ``str`` raw section title to be processed
     :returns: ``(str, datetime.datetime)``
     :raises: ``InvalidSectionTitle`` for non REP-0132 section titles
-    '''
+    """
     match = re.search(r'^([0-9]+\.[0-9]+\.[0-9]+)[ ]\((.+)\)$', title)
     if match is None:
         raise InvalidSectionTitle(title)
@@ -309,12 +311,15 @@ def version_and_date_from_title(title):
 
 
 class BulletList(object):
-    '''Represents a bulleted list of text'''
+    """Represent a bulleted list of text."""
+
     def __init__(self, bullets=None, bullet_type=None):
-        '''
+        """
+        Initialize BulletList.
+
         :param bullets: ``list(MixedText)`` list of text bullets
         :param bullet_type: ``str`` either 'bullet' or 'enumerated'
-        '''
+        """
         bullet_type = 'bullet' if bullet_type is None else bullet_type
         if bullet_type not in ['bullet', 'enumerated']:
             raise RuntimeError("Invalid bullet type: '{0}'".format(bullet_type))
@@ -357,9 +362,8 @@ class BulletList(object):
 
 
 class Changelog(object):
-    '''
-    Represents a REP-0132 changelog
-    '''
+    """Represents a REP-0132 changelog."""
+
     def __init__(self, package_name=None):
         self.__package_name = package_name
         self.__versions = []
@@ -401,8 +405,8 @@ class Changelog(object):
         self.__rst = rst
 
     def add_version_section(self, version, date, contents):
-        '''
-        Adds a version section
+        """
+        Add a version section.
 
         :param version: ``str`` version as a string
         :param date: ``datetime.datetime`` version date
@@ -410,7 +414,7 @@ class Changelog(object):
           of lists which contain a combination of ``str`` and
           ``Reference`` objects
         :returns: None
-        '''
+        """
         if version in self.__versions:
             raise DuplicateVersionsException(version)
         self.__parsed_versions.append(pkg_resources.parse_version(version))
@@ -421,51 +425,53 @@ class Changelog(object):
             parsed_v = pkg_resources.parse_version(v)
             index = self.__parsed_versions.index(parsed_v)
             if index == -1:
-                raise RuntimeError("Inconsistent internal version storage state")
+                raise RuntimeError('Inconsistent internal version storage state')
             new_versions[index] = v
         self.__versions = new_versions
         self.__dates[version] = date
         self.__content[version] = contents
 
     def foreach_version(self, reverse=False):
-        '''
-        Creates a generator for iterating over the versions, dates and content
+        """
+        Create a generator for iterating over the versions, dates and content.
 
         Versions are stored and iterated in order.
 
         :param reverse: ``bool`` if True then the iteration is reversed
         :returns: ``generator`` for iterating over versions, dates and content
-        '''
+        """
         for version in reversed(self.__versions) if reverse else self.__versions:
             yield version, self.__dates[version], self.__content[version]
 
     def get_date_of_version(self, version):
-        '''Returns date of a given version as a ``datetime.datetime``'''
+        """Return date of a given version as a ``datetime.datetime``."""
         if version not in self.__versions:
             raise KeyError("No date for version '{0}'".format(version))
         return self.__dates[version]
 
     def get_content_of_version(self, version):
-        '''
-        Returns changelog content for a given version
+        """
+        Return changelog content for a given version.
 
         :param version: ``str`` version
         :returns: ``list(list([str|Reference]))`` content expanded
-        '''
+        """
         if version not in self.__versions:
             raise KeyError("No content for version '{0}'".format(version))
         return self.__content[version]
 
 
 class DuplicateVersionsException(Exception):
-    '''Raised when more than one section per version is given'''
+    """Raised when more than one section per version is given."""
+
     def __init__(self, version):
         self.version = version
         Exception.__init__(self, "Version '{0}' is specified twice".format(version))
 
 
 class InvalidSectionTitle(Exception):
-    '''raised on non REP-0132 section titles'''
+    """raised on non REP-0132 section titles."""
+
     def __init__(self, title):
         self.title = title
         msg = "Section title does not conform to REP-0132: '{0}'".format(title)
@@ -473,7 +479,8 @@ class InvalidSectionTitle(Exception):
 
 
 class MixedText(object):
-    '''Represents text mixed with references and nested bullets'''
+    """Represents text mixed with references and nested bullets."""
+
     def __init__(self, texts=[]):
         self.texts = list(texts)
 
@@ -503,9 +510,8 @@ class MixedText(object):
 
 
 class Reference(object):
-    '''
-    Represents a piece of text with an associated link
-    '''
+    """Represents a piece of text with an associated link."""
+
     def __init__(self, text, link):
         self.text = text
         self.link = link
@@ -520,20 +526,21 @@ class Reference(object):
         return self.as_txt()
 
     def as_rst(self):
-        '''Self as rst (unicode)'''
+        """Self as rst (unicode)."""
         if self.text is None:
             return _unicode(self.link)
-        return "`{0} <{1}>`_".format(self.text, self.link)
+        return '`{0} <{1}>`_'.format(self.text, self.link)
 
     def as_txt(self):
-        '''Self formatted for plain text (unicode)'''
+        """Self formatted for plain text (unicode)."""
         if self.text is None:
             return _unicode(self.link)
-        return "{0} <{1}>".format(self.text, self.link)
+        return '{0} <{1}>'.format(self.text, self.link)
 
 
 class Transition(object):
-    '''Represents a trasition element from ReST'''
+    """Represents a trasition element from ReST."""
+
     def __str__(self):
         value = self.__unicode__()
         if not _py3:
