@@ -43,6 +43,11 @@ import xml.dom.minidom as dom
 from catkin_pkg.condition import evaluate_condition
 
 PACKAGE_MANIFEST_FILENAME = 'package.xml'
+PACKAGE_MANIFEST_SCHEMA_URLS = [
+    'http://download.ros.org/schema/package_format1.xsd',
+    'http://download.ros.org/schema/package_format2.xsd',
+    'http://download.ros.org/schema/package_format3.xsd',
+]
 
 
 class Package(object):
@@ -138,7 +143,7 @@ class Package(object):
         :returns: True if the given package buildtool depends on catkin
         :rtype: bool
         """
-        return 'catkin' in [d.name for d in self.buildtool_depends]
+        return 'catkin' in (d.name for d in self.buildtool_depends)
 
     def get_build_type(self):
         """
@@ -178,7 +183,7 @@ class Package(object):
         :returns: True if metapackage, else False
         :rtype: bool
         """
-        return 'metapackage' in [e.tagname for e in self.exports]
+        return 'metapackage' in (e.tagname for e in self.exports)
 
     def evaluate_conditions(self, context):
         """
@@ -232,12 +237,12 @@ class Package(object):
                     'Package name "%s" does not follow the naming conventions. It should start with '
                     'a lower case letter and only contain lower case letters, digits, underscores, and dashes.' % self.name)
 
-        version_regexp = '^[0-9]+\.[0-9]+\.[0-9]+$'
+        version_regexp = r'^[0-9]+\.[0-9]+\.[0-9]+$'
         if not self.version:
             errors.append('Package version must not be empty')
         elif not re.match(version_regexp, self.version):
             errors.append('Package version "%s" does not follow version conventions' % self.version)
-        elif not re.match('^(0|[1-9][0-9]*)\.(0|[1-9][0-9]*)\.(0|[1-9][0-9]*)$', self.version):
+        elif not re.match(r'^(0|[1-9][0-9]*)\.(0|[1-9][0-9]*)\.(0|[1-9][0-9]*)$', self.version):
             new_warnings.append('Package "%s" does not follow the version conventions. It should not contain leading zeros (unless the number is 0).' % self.name)
         if self.version_compatibility:
             if not re.match(version_regexp, self.version_compatibility):
@@ -341,6 +346,14 @@ class Dependency(object):
     def __str__(self):
         return self.name
 
+    def __repr__(self):
+        kv = []
+        for slot in self.__slots__:
+            attr = getattr(self, slot, None)
+            if attr is not None:
+                kv.append('{}={!r}'.format(slot, attr))
+        return '{}({})'.format(self.__class__.__name__, ', '.join(kv))
+
     def evaluate_condition(self, context):
         """
         Evaluate the condition.
@@ -420,7 +433,7 @@ class Person(object):
     def validate(self):
         if self.email is None:
             return
-        if not re.match('^[-a-zA-Z0-9_%+]+(\.[-a-zA-Z0-9_%+]+)*@[-a-zA-Z0-9%]+(\.[-a-zA-Z0-9%]+)*\.[a-zA-Z]{2,}$', self.email):
+        if not re.match(r'^[-a-zA-Z0-9_%+]+(\.[-a-zA-Z0-9_%+]+)*@[-a-zA-Z0-9%]+(\.[-a-zA-Z0-9%]+)*\.[a-zA-Z]{2,}$', self.email):
             raise InvalidPackage('Invalid email "%s" for person "%s"' % (self.email, self.name))
 
 
@@ -498,6 +511,49 @@ def _get_package_xml(path):
         return f.read(), filename
 
 
+def has_ros_schema_reference(path):
+    """
+    Check if the XML file contains a processing instruction referencing a ROS package manifest schema.
+
+    :param path: The path of the package.xml file, it may or may not
+        include the filename
+    :type path: str
+    :returns: True if it contains the known reference, else False
+    :rtype: bool
+    :raises: :exc:`IOError`
+    """
+    xml, _ = _get_package_xml(path)
+    return has_ros_schema_reference_string(xml)
+
+
+def has_ros_schema_reference_string(data):
+    """
+    Check if the XML data contains a processing instruction referencing a ROS package manifest schema.
+
+    :param data: package.xml contents
+    :type data: str
+    :returns: True if it contains the known reference, else False
+    :rtype: bool
+    """
+    if sys.version_info[0] == 2 and not isinstance(data, str):
+        data = data.encode('utf-8')
+    try:
+        root = dom.parseString(data)
+    except Exception:
+        # invalid XML
+        return False
+
+    for child in root.childNodes:
+        if child.nodeType == child.PROCESSING_INSTRUCTION_NODE:
+            if child.target == 'xml-model':
+                # extract schema url from "xml-model" processing instruction
+                schema_url = re.search(r'href="([A-Za-z0-9\._/:]*)"', child.data).group(1)
+                if schema_url in PACKAGE_MANIFEST_SCHEMA_URLS:
+                    return True
+
+    return False
+
+
 def parse_package(path, warnings=None):
     """
     Parse package manifest.
@@ -534,6 +590,8 @@ def parse_package_string(data, filename=None, warnings=None):
     :returns: return parsed :class:`Package`
     :raises: :exc:`InvalidPackage`
     """
+    if sys.version_info[0] == 2 and not isinstance(data, str):
+        data = data.encode('utf-8')
     try:
         root = dom.parseString(data)
     except Exception as ex:
@@ -697,7 +755,11 @@ def parse_package_string(data, filename=None, warnings=None):
     nodes = [n for n in root.childNodes if n.nodeType == n.ELEMENT_NODE]
     unknown_tags = set([n.tagName for n in nodes if n.tagName not in known.keys()])
     if unknown_tags:
-        errors.append('The manifest (with format version %d) must not contain the following tags: %s' % (pkg.package_format, ', '.join(unknown_tags)))
+        errors.append('The manifest of package "%s" (with format version %d) must not contain the following tags: %s' % (pkg.name, pkg.package_format, ', '.join(unknown_tags)))
+    if 'run_depend' in unknown_tags and pkg.package_format >= 2:
+        errors.append('Please replace <run_depend> tags with <exec_depend> tags.')
+    elif 'exec_depend' in unknown_tags and pkg.package_format < 2:
+        errors.append('Either update to a newer format or replace <exec_depend> tags with <run_depend> tags.')
     for node in [n for n in nodes if n.tagName in known.keys()]:
         errors += _check_known_attributes(node, known[node.tagName])
         if node.tagName not in ['description', 'export']:
