@@ -7,12 +7,15 @@ import xml.dom.minidom as dom
 
 from catkin_pkg.package import (
     _check_known_attributes,
+    _get_package_xml,
     Dependency,
     Export,
+    has_ros_schema_reference_string,
     InvalidPackage,
     License,
     Package,
     parse_package,
+    parse_package_string,
     Person,
 )
 
@@ -115,6 +118,14 @@ class PackageTest(unittest.TestCase):
         dep = Dependency('foo', condition='foo <= bar or bar >= baz')
         self.assertFalse(dep.evaluate_condition({}))
 
+    def test_dependency_repr(self):
+        dep = Dependency('foo', condition='$foo == 2')
+        assert repr(dep) == "Dependency(name='foo', condition='$foo == 2')"
+        self.assertTrue(dep.evaluate_condition({'foo': 2}))
+        assert repr(dep) == "Dependency(name='foo', condition='$foo == 2', evaluated_condition=True)"
+        self.assertFalse(dep.evaluate_condition({'foo': 3}))
+        assert repr(dep) == "Dependency(name='foo', condition='$foo == 2', evaluated_condition=False)"
+
     def test_init_kwargs_string(self):
         pack = Package('foo',
                        name='bar',
@@ -321,3 +332,41 @@ class PackageTest(unittest.TestCase):
     def test_parse_package_invalid(self):
         filename = os.path.join(test_data_dir, 'invalid_package.xml')
         self.assertRaises(InvalidPackage, parse_package, filename)
+
+    def test_parse_package_string(self):
+        filename = os.path.join(test_data_dir, 'valid_package.xml')
+        xml = _get_package_xml(filename)[0]
+
+        assert isinstance(xml, str)
+        parse_package_string(xml)
+
+        if sys.version_info[0] == 2:
+            xml = xml.decode('utf-8')
+            assert not isinstance(xml, str)
+        else:
+            xml = xml.encode('utf-8')
+            assert isinstance(xml, bytes)
+        parse_package_string(xml)
+
+    def test_has_ros_schema_reference_string(self):
+        self.assertFalse(
+            has_ros_schema_reference_string(
+                """\
+<?xml version="1.0"?>
+<?xml-model href="http://some.url/to/a_wrong_schema.xsd" schematypens="http://www.w3.org/2001/XMLSchema"?>
+<package/>
+"""))
+        self.assertFalse(
+            has_ros_schema_reference_string(
+                """\
+<?xml version="1.0"?>
+<package/>
+"""))
+        for format_version in (1, 2, 3):
+            self.assertTrue(
+                has_ros_schema_reference_string(
+                    """\
+<?xml version="1.0"?>
+<?xml-model href="http://download.ros.org/schema/package_format%d.xsd" schematypens="http://www.w3.org/2001/XMLSchema"?>
+<package/>
+""" % format_version))
